__author__ = "Lukas Leufen"
__date__ = '2019-11-14'


import logging
import argparse
from src.experiment_setup import ExperimentSetup
from src.modules import run, PreProcessing, Training, PostProcessing


def main():

    with run():
        exp_setup = ExperimentSetup(args, trainable=True, stations=['DEBW107', 'DEBY081', 'DEBW013', 'DEBW076', 'DEBW087'])

        PreProcessing(exp_setup)

        Training(exp_setup)

        PostProcessing(exp_setup)


if __name__ == "__main__":

    formatter = '%(asctime)s - %(levelname)s: %(message)s  [%(filename)s:%(funcName)s:%(lineno)s]'
    logging.basicConfig(format=formatter, level=logging.INFO)

    parser = argparse.ArgumentParser()
    parser.add_argument('--experiment_date', metavar='--exp_date', type=str, nargs=1, default=None,
                        help="set experiment date as string")
    args = parser.parse_args()

    main()
